@@ -1,9 +1,18 @@
-VERSION = "0.3.13"
+VERSION = "0.3.13.1"
 PYTHONDIR = "/usr/local/lib/python2.5/site-packages"
 BIN_DIR = "/usr/local/bin"
 LIB_DIR = "/usr/local/lib"
 LOCALE_DIR = "${prefix}/share/locale"
 SHARED_DATA_DIR = "/usr/local/share/conduit"
 SHARED_MODULE_DIR = "/usr/local/lib/conduit/modules"
+
+#
+# Platform specific implementations
+#
+
+#{gtkmozembed, webkit, system}
+BROWSER_IMPL = "gtkmozembed"
+
+#{GConf,Python}
 SETTINGS_IMPL = "GConf"
 
